@@ -52,4 +52,13 @@ def ActivateCellDoneSound(url='http://soundfxcenter.com/movies/star-wars/8d82b5_
           Plays a ding when a cell is complete. Kind of buggy with a failed cell.
         example call:
             CellDoneChime()'''
-    load_ipython_extension(get_ipython(),url)
\ No newline at end of file
+    load_ipython_extension(get_ipython(),url)
+
+#-------------------------------------------------------------------------------------
+from IPython.core.display import display, HTML
+def FitCellsToWindow():
+  '''brief:
+          Fits Jupyter cells to window size.
+        example call:
+            FitCellsToWindow()'''
+  display(HTML("<style>.container { width:100% !important; }</style>"))
\ No newline at end of file
